<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Compatibility {

    protected $is_current_editor_gutenberg = false;

	public function __construct() {
		$this->wp_importer_esacpe(); // WordPress Default Importer JSON slash issue
		add_action( 'admin_print_scripts-edit.php', array( $this, 'wppb_add_btn_to_gutenburg_dropdown'), 20 ); // Gutenburg
		add_action( 'init', array( $this, 'add_image_size'), 30 );  // Image Size Add for Post Addons

		add_action( 'updated_post_meta', array( $this, 'thirdparty_pagebuilder_comparability_check' ) , 12, 4 );
		
		if(version_compare(WPPB_VERSION, '1.2.0', '>=')){
			add_action( 'admin_init', array( $this, 'wppb_replace_font_awesome_icon_class' ));
		}

		if( defined('GIVE_VERSION') ){
			add_action( 'wppb_enqueue_scripts_in_editor', array( $this, 'wppb_give_compatibility' ) ); // Give Plugins Compatibility
		}


		/**
         * Gutenberg
         */

        if (is_admin()){
	        add_action('admin_body_class', array($this, 'add_extra_body_class'));
	        add_action( 'enqueue_block_editor_assets', array($this, 'add_required_assets') );
	        add_action( 'admin_footer', array($this, 'add_required_template_to_guttenberg_editor') );
        }
	}

	/**
	 * @since 1.0.2
	 * Give Plugins Compatibility Callback
	 */
	public function wppb_give_compatibility(){
		wp_deregister_script( 'give' );
	}

	/**
	 * Thirdparty Page builder Comparability Check
	 * @since v 1.0.0
	 */
	function thirdparty_pagebuilder_comparability_check( $meta_id, $post_id, $meta_key, $meta_value ){
		if( $meta_key == '_wppb_content' ){
			update_post_meta( $post_id , '_wppb_current_post_editor', 'wppb_builder_activated' );
		}else{
			if( ($meta_key == '_elementor_data') || // Elementor
			    ($meta_key == '_themify_builder_settings_json') || // Themify
			    ($meta_key == '_et_pb_use_builder' &&  $meta_value == 'on' ) || // Divi
			    ($meta_key == '_wpb_vc_js_status' &&  $meta_value == 'true' ) || // Visual Composer
			    ($meta_key == 'panels_data') // SiteOrigin
			){
				delete_post_meta( $post_id, '_wppb_current_post_editor' );
			}
		}
	}


 	/**
	 * Replace FontAwesome 4 class with FontAwesome 5
	 * @since v 1.2.1
	 */
	function wppb_replace_font_awesome_icon_class(){
		if ( get_option( 'wppb_fontawesome_five_upgrade' ) != 'completed' ) {	
			global $wpdb;
			$results  = $wpdb->get_results( "SELECT post_id, meta_value  FROM $wpdb->postmeta WHERE meta_key = '_wppb_content'" );

			$replace_to = $this->font_awesome_4_icon_class_list();
			$replace_by = $this->font_awesome_5_icon_class_list();

			foreach($results as $result) {
				$data = preg_replace($replace_to, $replace_by, $result->meta_value);
				update_post_meta( $result->post_id, '_wppb_content', addslashes($data) );
			}
			update_option( 'wppb_fontawesome_five_upgrade', 'completed' );
		}
	}

	/**
	 * FontAwesome 4 Icon class list
	 * @since v 1.2.1
	 */
	public function font_awesome_4_icon_class_list(){
		$replace_to = array(
			'/fa fa-zhihu/', '/fa fa-youtube-square/', '/fa fa-youtube-play/', '/fa fa-yoast/', '/fa fa-yin-yang/', '/fa fa-yelp/', '/fa fa-yc/', '/fa fa-yarn/', '/fa fa-yandex-international/', '/fa fa-yandex/', '/fa fa-yammer/', '/fa fa-yahoo/', '/fa fa-y-combinator-square/', '/fa fa-xing-square/', '/fa fa-xing/', '/fa fa-xbox/', '/fa fa-x-ray/', '/fa fa-wrench/', '/fa fa-wpressr/', '/fa fa-wpforms/', '/fa fa-wpexplorer/', '/fa fa-wpbeginner/', '/fa fa-wordpress-simple/', '/fa fa-wordpress/', '/fa fa-wolf-pack-battalion/', '/fa fa-wizards-of-the-coast/', '/fa fa-wix/', '/fa fa-wine-glass-alt/', '/fa fa-wine-glass/', '/fa fa-wine-bottle/', '/fa fa-windows/', '/fa fa-window-restore/', '/fa fa-window-restore/', '/fa fa-window-minimize/', '/fa fa-window-minimize/', '/fa fa-window-maximize/', '/fa fa-window-maximize/', '/fa fa-wind/', '/fa fa-wikipedia-w/', '/fa fa-wifi/', '/fa fa-whmcs/', '/fa fa-wheelchair-alt/', '/fa fa-wheelchair/', '/fa fa-whatsapp-square/', '/fa fa-whatsapp/', '/fa fa-weight-hanging/', '/fa fa-weight/', '/fa fa-weibo/', '/fa fa-weebly/', '/fa fa-wechat/', '/fa fa-waze/', '/fa fa-wave-square/', '/fa fa-water/', '/fa fa-warning/', '/fa fa-warehouse/', '/fa fa-wallet/', '/fa fa-walking/', '/fa fa-vuejs/', '/fa fa-vr-cardboard/', '/fa fa-vote-yea/', '/fa fa-volume-up/', '/fa fa-volume-off/', '/fa fa-volume-mute/', '/fa fa-volume-down/', '/fa fa-volume-control-phone/', '/fa fa-volleyball-ball/', '/fa fa-voicemail/', '/fa fa-vnv/', '/fa fa-vk/', '/fa fa-vine/', '/fa fa-vimeo-square/', '/fa fa-vimeo/', '/fa fa-vimeo/', '/fa fa-vihara/', '/fa fa-video-slash/', '/fa fa-video/', '/fa fa-viber/', '/fa fa-vials/', '/fa fa-vial/', '/fa fa-viadeo-square/', '/fa fa-viadeo/', '/fa fa-viacoin/', '/fa fa-venus-mars/', '/fa fa-venus-double/', '/fa fa-venus/', '/fa fa-vector-square/', '/fa fa-vcard/', '/fa fa-vaadin/', '/fa fa-ussunnah/', '/fa fa-usps/', '/fa fa-users-cog/', '/fa fa-user-times/', '/fa fa-user-tie/', '/fa fa-user-tag/', '/fa fa-user-slash/', '/fa fa-user-shield/', '/fa fa-user-secret/', '/fa fa-user-plus/', '/fa fa-user-o/', '/fa fa-user-nurse/', '/fa fa-user-ninja/', '/fa fa-user-minus/', '/fa fa-user-md/', '/fa fa-user-lock/', '/fa fa-user-injured/', '/fa fa-user-graduate/', '/fa fa-user-friends/', '/fa fa-user-edit/', '/fa fa-user-cog/', '/fa fa-user-clock/', '/fa fa-user-circle-o/', '/fa fa-user-circle/', '/fa fa-user-check/', '/fa fa-user-astronaut/', '/fa fa-user-alt-slash/', '/fa fa-user-alt/', '/fa fa-user/', '/fa fa-usb/', '/fa fa-ups/', '/fa fa-upload/', '/fa fa-untappd/', '/fa fa-unsorted/', '/fa fa-unlock-alt/', '/fa fa-unlock/', '/fa fa-universal-access/', '/fa fa-uniregistry/', '/fa fa-undo-alt/', '/fa fa-underline/', '/fa fa-umbrella-beach/', '/fa fa-umbrella/', '/fa fa-uikit/', '/fa fa-ubuntu/', '/fa fa-uber/', '/fa fa-typo3/', '/fa fa-twitter-square/', '/fa fa-twitter/', '/fa fa-twitch/', '/fa fa-tumblr-square/', '/fa fa-tumblr/', '/fa fa-tty/', '/fa fa-tshirt/', '/fa fa-try/', '/fa fa-truck-pickup/', '/fa fa-truck-moving/', '/fa fa-truck-monster/', '/fa fa-truck-loading/', '/fa fa-truck/', '/fa fa-trophy/', '/fa fa-tripadvisor/', '/fa fa-trello/', '/fa fa-tree/', '/fa fa-trash-restore-alt/', '/fa fa-trash-restore/', '/fa fa-trash-o/', '/fa fa-trash/', '/fa fa-trash/', '/fa fa-transgender-alt/', '/fa fa-tram/', '/fa fa-train/', '/fa fa-traffic-light/', '/fa fa-trademark/', '/fa fa-trade-federation/', '/fa fa-tractor/', '/fa fa-torii-gate/', '/fa fa-torah/', '/fa fa-tooth/', '/fa fa-tools/', '/fa fa-toolbox/', '/fa fa-toilet-paper/', '/fa fa-toilet/', '/fa fa-toggle-up/', '/fa fa-toggle-right/', '/fa fa-toggle-on/', '/fa fa-toggle-off/', '/fa fa-toggle-left/', '/fa fa-toggle-down/', '/fa fa-tired/', '/fa fa-tired/', '/fa fa-tint-slash/', '/fa fa-tint/', '/fa fa-times-rectangle-o/', '/fa fa-times-rectangle/', '/fa fa-times-circle-o/', '/fa fa-times-circle/', '/fa fa-ticket/', '/fa fa-thumbs-up/', '/fa fa-thumbs-o-up/', '/fa fa-thumbs-o-down/', '/fa fa-thumbs-down/', '/fa fa-thumb-tack/', '/fa fa-think-peaks/', '/fa fa-thermometer-three-3/', '/fa fa-thermometer-2/', '/fa fa-thermometer-1/', '/fa fa-thermometer-0/', '/fa fa-thermometer/', '/fa fa-thermometer/', '/fa fa-themeisle/', '/fa fa-themeco/', '/fa fa-theater-masks/', '/fa fa-the-red-yeti/', '/fa fa-th-list/', '/fa fa-th-large/', '/fa fa-th/', '/fa fa-text-width/', '/fa fa-text-height/', '/fa fa-terminal/', '/fa fa-tenge/', '/fa fa-tencent-weibo/', '/fa fa-temperature-low/', '/fa fa-temperature-high/', '/fa fa-television/', '/fa fa-telegram-plane/', '/fa fa-telegram/', '/fa fa-teeth-open/', '/fa fa-teeth/', '/fa fa-teamspeak/', '/fa fa-tasks/', '/fa fa-tape/', '/fa fa-tags/', '/fa fa-tag/', '/fa fa-tablets/', '/fa fa-tablet/', '/fa fa-tablet/', '/fa fa-table-tennis/', '/fa fa-table/', '/fa fa-syringe/', '/fa fa-sync-alt/', '/fa fa-synagogue/', '/fa fa-symfony/', '/fa fa-swimming-pool/', '/fa fa-swimmer/', '/fa fa-swatchbook/', '/fa fa-suse/', '/fa fa-surprise/', '/fa fa-surprise/', '/fa fa-supple/', '/fa fa-superscript/', '/fa fa-superpowers/', '/fa fa-sun-o/', '/fa fa-sun/', '/fa fa-suitcase-rolling/', '/fa fa-suitcase/', '/fa fa-subway/', '/fa fa-subscript/', '/fa fa-stumbleupon-circle/', '/fa fa-stumbleupon/', '/fa fa-studiovinari/', '/fa fa-stroopwafel/', '/fa fa-stripe-s/', '/fa fa-stripe/', '/fa fa-strikethrough/', '/fa fa-street-view/', '/fa fa-stream/', '/fa fa-strava/', '/fa fa-store-alt/', '/fa fa-store/', '/fa fa-stopwatch/', '/fa fa-stop-circle-o/', '/fa fa-stop-circle/', '/fa fa-stop/', '/fa fa-sticky-note-o/', '/fa fa-sticky-note/', '/fa fa-sticker-mule/', '/fa fa-stethoscope/', '/fa fa-step-forward/', '/fa fa-step-backward/', '/fa fa-steam-symbol/', '/fa fa-steam-square/', '/fa fa-steam/', '/fa fa-staylinked/', '/fa fa-star-of-life/', '/fa fa-star-of-david/', '/fa fa-star-o/', '/fa fa-star-half-empty/', '/fa fa-star-half-alt/', '/fa fa-star-full/', '/fa fa-star-and-crescent/', '/fa fa-star/', '/fa fa-stamp/', '/fa fa-stackpath/', '/fa fa-stack-overflow/', '/fa fa-stack-exchange/', '/fa fa-squarespace/', '/fa fa-square-root-alt/', '/fa fa-square-full/', '/fa fa-square/', '/fa fa-square/', '/fa fa-spray-can/', '/fa fa-spotify/', '/fa fa-spoon/', '/fa fa-splotch/', '/fa fa-spinner/', '/fa fa-spider/', '/fa fa-spell-check/', '/fa fa-speaker-deck/', '/fa fa-speakap/', '/fa fa-space-shuttle/', '/fa fa-spa/', '/fa fa-sourcetree/', '/fa fa-soundcloud/', '/fa fa-sort-numeric-up-alt/', '/fa fa-sort-numeric-down-alt/', '/fa fa-sort-numeric-desc/', '/fa fa-sort-numeric-asc/', '/fa fa-sort-desc/', '/fa fa-sort-asc/', '/fa fa-sort-amount-up-alt/', '/fa fa-sort-amount-down-alt/', '/fa fa-sort-amount-desc/', '/fa fa-sort-amount-asc/', '/fa fa-sort-alpha-up-alt/', '/fa fa-sort-alpha-down-alt/', '/fa fa-sort-alpha-desc/', '/fa fa-sort-alpha-asc/', '/fa fa-solar-panel/', '/fa fa-socks/', '/fa fa-soccer-ball-o/', '/fa fa-snowplow/', '/fa fa-snowman/', '/fa fa-snowflake-o/', '/fa fa-snowflake/', '/fa fa-snowboarding/', '/fa fa-snapchat-square/', '/fa fa-snapchat-ghost/', '/fa fa-snapchat/', '/fa fa-sms/', '/fa fa-smoking-ban/', '/fa fa-smoking/', '/fa fa-smog/', '/fa fa-smile-wink/', '/fa fa-smile-wink/', '/fa fa-smile-o/', '/fa fa-smile-beam/', '/fa fa-smile-beam/', '/fa fa-smile/', '/fa fa-slideshare/', '/fa fa-sliders/', '/fa fa-sleigh/', '/fa fa-slash/', '/fa fa-slack-hash/', '/fa fa-slack/', '/fa fa-skype/', '/fa fa-skyatlas/', '/fa fa-skull-crossbones/', '/fa fa-skull/', '/fa fa-skiing-nordic/', '/fa fa-skiing/', '/fa fa-sketch/', '/fa fa-skating/', '/fa fa-sith/', '/fa fa-sitemap/', '/fa fa-sistrix/', '/fa fa-simplybuilt/', '/fa fa-sim-card/', '/fa fa-signing/', '/fa fa-signature/', '/fa fa-signal/', '/fa fa-sign-out/', '/fa fa-sign-in/', '/fa fa-sign/', '/fa fa-shuttle-van/', '/fa fa-shower/', '/fa fa-shopware/', '/fa fa-shopping-cart/', '/fa fa-shopping-basket/', '/fa fa-shopping-bag/', '/fa fa-shoe-prints/', '/fa fa-shirtsinbulk/', '/fa fa-shipping-fast/', '/fa fa-ship/', '/fa fa-shield/', '/fa fa-share-square-o/', '/fa fa-share-square/', '/fa fa-share-alt-square/', '/fa fa-share-alt/', '/fa fa-shapes/', '/fa fa-servicestack/', '/fa fa-server/', '/fa fa-send/', '/fa fa-sellsy/', '/fa fa-seedling/', '/fa fa-searchengin/', '/fa fa-search-plus/', '/fa fa-search-minus/', '/fa fa-search-location/', '/fa fa-search-dollar/', '/fa fa-search/', '/fa fa-sd-card/', '/fa fa-scroll/', '/fa fa-scribd/', '/fa fa-screwdriver/', '/fa fa-scissors/', '/fa fa-school/', '/fa fa-schlix/', '/fa fa-save/', '/fa fa-satellite-dish/', '/fa fa-satellite/', '/fa fa-sass/', '/fa fa-salesforce/', '/fa fa-safari/', '/fa fa-sad-tear/', '/fa fa-sad-tear/', '/fa fa-sad-cry/', '/fa fa-sad-cry/', '/fa fa-running/', '/fa fa-ruler-vertical/', '/fa fa-ruler-horizontal/', '/fa fa-ruler-combined/', '/fa fa-ruler/', '/fa fa-ruble/', '/fa fa-rss-square/', '/fa fa-route/', '/fa fa-rotate-left/', '/fa fa-rockrms/', '/fa fa-rocketchat/', '/fa fa-rocket/', '/fa fa-robot/', '/fa fa-road/', '/fa fa-ring/', '/fa fa-ribbon/', '/fa fa-rev/', '/fa fa-retweet/', '/fa fa-restroom/', '/fa fa-resolving/', '/fa fa-researchgate/', '/fa fa-republican/', '/fa fa-replyd/', '/fa fa-repeat/', '/fa fa-renren/', '/fa fa-remove-format/', '/fa fa-registered/', '/fa fa-registered/', '/fa fa-refresh/', '/fa fa-redo-alt/', '/fa fa-redhat/', '/fa fa-reddit-square/', '/fa fa-reddit-alien/', '/fa fa-reddit/', '/fa fa-red-river/', '/fa fa-recycle/', '/fa fa-receipt/', '/fa fa-readme/', '/fa fa-reacteurope/', '/fa fa-react/', '/fa fa-ravelry/', '/fa fa-raspberry-pi/', '/fa fa-random/', '/fa fa-rainbow/', '/fa fa-radiation-alt/', '/fa fa-radiation/', '/fa fa-ra/', '/fa fa-r-project/', '/fa fa-quran/', '/fa fa-quote-right/', '/fa fa-quote-left/', '/fa fa-quora/', '/fa fa-quinscape/', '/fa fa-quidditch/', '/fa fa-question-circle-o/', '/fa fa-question-circle/', '/fa fa-question/', '/fa fa-qrcode/', '/fa fa-qq/', '/fa fa-python/', '/fa fa-puzzle-piece/', '/fa fa-pushed/', '/fa fa-project-diagram/', '/fa fa-product-hunt/', '/fa fa-procedures/', '/fa fa-print/', '/fa fa-prescription-bottle-alt/', '/fa fa-prescription-bottle/', '/fa fa-prescription/', '/fa fa-praying-hands/', '/fa fa-pray/', '/fa fa-power-off/', '/fa fa-portrait/', '/fa fa-poop/', '/fa fa-poo-storm/', '/fa fa-poo/', '/fa fa-poll-h/', '/fa fa-poll/', '/fa fa-podcast/', '/fa fa-plus-square-o/', '/fa fa-plus-square/', '/fa fa-plus-circle/', '/fa fa-plus/', '/fa fa-plug/', '/fa fa-playstation/', '/fa fa-play-circle-o/', '/fa fa-play-circle/', '/fa fa-play/', '/fa fa-plane-departure/', '/fa fa-plane-arrival/', '/fa fa-plane/', '/fa fa-place-of-worship/', '/fa fa-pizza-slice/', '/fa fa-pinterest-square/', '/fa fa-pinterest-p/', '/fa fa-pinterest/', '/fa fa-pills/', '/fa fa-piggy-bank/', '/fa fa-pied-piper-pp/', '/fa fa-pied-piper-hat/', '/fa fa-pied-piper-alt/', '/fa fa-pied-piper/', '/fa fa-pie-chart/', '/fa fa-picture-o/', '/fa fa-php/', '/fa fa-photo-video/', '/fa fa-photo/', '/fa fa-phone-square-alt/', '/fa fa-phone-square/', '/fa fa-phone-slash/', '/fa fa-phone-alt/', '/fa fa-phone/', '/fa fa-phoenix-squadron/', '/fa fa-phoenix-framework/', '/fa fa-phabricator/', '/fa fa-person-booth/', '/fa fa-periscope/', '/fa fa-percentage/', '/fa fa-percent/', '/fa fa-pepper-hot/', '/fa fa-people-carry/', '/fa fa-penny-arcade/', '/fa fa-pencil-square-o/', '/fa fa-pencil-ruler/', '/fa fa-pencil/', '/fa fa-pen-square/', '/fa fa-pen-nib/', '/fa fa-pen-fancy/', '/fa fa-pen-alt/', '/fa fa-pen/', '/fa fa-peace/', '/fa fa-paypal/', '/fa fa-paw/', '/fa fa-pause-circle-o/', '/fa fa-pause-circle/', '/fa fa-pause/', '/fa fa-patreon/', '/fa fa-paste/', '/fa fa-paste/', '/fa fa-pastafasianism/', '/fa fa-passport/', '/fa fa-parking/', '/fa fa-paragraph/', '/fa fa-parachute-box/', '/fa fa-paperclip/', '/fa fa-paper-plane-o/', '/fa fa-pallet/', '/fa fa-palfed/', '/fa fa-palette/', '/fa fa-paint-roller/', '/fa fa-paint-brush/', '/fa fa-pager/', '/fa fa-pagelines/', '/fa fa-page4/', '/fa fa-otter/', '/fa fa-osi/', '/fa fa-optin-monster/', '/fa fa-opera/', '/fa fa-openid/', '/fa fa-opencart/', '/fa fa-om/', '/fa fa-old-republic/', '/fa fa-oil-can/', '/fa fa-odnoklassniki-square/', '/fa fa-odnoklassniki/', '/fa fa-object-ungroup/', '/fa fa-object-ungroup/', '/fa fa-object-group/', '/fa fa-object-group/', '/fa fa-nutritionix/', '/fa fa-ns8/', '/fa fa-npm/', '/fa fa-notes-medical/', '/fa fa-not-equal/', '/fa fa-node-js/', '/fa fa-node/', '/fa fa-nimblr/', '/fa fa-newspaper-o/', '/fa fa-newspaper/', '/fa fa-neuter/', '/fa fa-network-wired/', '/fa fa-neos/', '/fa fa-navicon/', '/fa fa-napster/', '/fa fa-music/', '/fa fa-mug-hot/', '/fa fa-mouse-pointer/', '/fa fa-mountain/', '/fa fa-motorcycle/', '/fa fa-mosque/', '/fa fa-mortar-pestle/', '/fa fa-mortar-board/', '/fa fa-moon-o/', '/fa fa-moon/', '/fa fa-monument/', '/fa fa-money-check-alt/', '/fa fa-money-check/', '/fa fa-money-bill-wave-alt/', '/fa fa-money-bill-wave/', '/fa fa-money-bill-alt/', '/fa fa-money-bill/', '/fa fa-money/', '/fa fa-monero/', '/fa fa-modx/', '/fa fa-mobile/', '/fa fa-mobile/', '/fa fa-mizuni/', '/fa fa-mixcloud/', '/fa fa-mix/', '/fa fa-mitten/', '/fa fa-minus-square-o/', '/fa fa-minus-square/', '/fa fa-minus-circle/', '/fa fa-minus/', '/fa fa-microsoft/', '/fa fa-microscope/', '/fa fa-microphone-slash/', '/fa fa-microphone-alt-slash/', '/fa fa-microphone-alt/', '/fa fa-microphone/', '/fa fa-microchip/', '/fa fa-meteor/', '/fa fa-mercury/', '/fa fa-menorah/', '/fa fa-mendeley/', '/fa fa-memory/', '/fa fa-meh-rolling-eyes/', '/fa fa-meh-rolling-eyes/', '/fa fa-meh-o/', '/fa fa-meh-blank/', '/fa fa-meh-blank/', '/fa fa-meh/', '/fa fa-megaport/', '/fa fa-meetup/', '/fa fa-medrt/', '/fa fa-medkit/', '/fa fa-medium-m/', '/fa fa-medium/', '/fa fa-medapps/', '/fa fa-medal/', '/fa fa-maxcdn/', '/fa fa-mastodon/', '/fa fa-mask/', '/fa fa-mars-stroke-v/', '/fa fa-mars-stroke-h/', '/fa fa-mars-stroke/', '/fa fa-mars-double/', '/fa fa-mars/', '/fa fa-marker/', '/fa fa-markdown/', '/fa fa-map-signs/', '/fa fa-map-pin/', '/fa fa-map-o/', '/fa fa-map-marker/', '/fa fa-map-marker/', '/fa fa-map-marked-alt/', '/fa fa-map-marked/', '/fa fa-map/', '/fa fa-mandalorian/', '/fa fa-male/', '/fa fa-mailchimp/', '/fa fa-mail-reply-all/', '/fa fa-mail-reply/', '/fa fa-mail-forward/', '/fa fa-mail-bulk/', '/fa fa-magnet/', '/fa fa-magic/', '/fa fa-magento/', '/fa fa-lyft/', '/fa fa-luggage-cart/', '/fa fa-low-vision/', '/fa fa-long-arrow-up/', '/fa fa-long-arrow-right/', '/fa fa-long-arrow-left/', '/fa fa-long-arrow-down/', '/fa fa-lock-open/', '/fa fa-lock/', '/fa fa-location-arrow/', '/fa fa-list-ul/', '/fa fa-list-ol/', '/fa fa-list-alt/', '/fa fa-list-alt/', '/fa fa-list/', '/fa fa-linux/', '/fa fa-linode/', '/fa fa-linkedin-square/', '/fa fa-linkedin/', '/fa fa-line/', '/fa fa-lightbulb-o/', '/fa fa-lightbulb/', '/fa fa-life-saver/', '/fa fa-life-bouy/', '/fa fa-level-up/', '/fa fa-level-down/', '/fa fa-less-than-equal/', '/fa fa-less-than/', '/fa fa-less/', '/fa fa-lemon-o/', '/fa fa-lemon/', '/fa fa-leanpub/', '/fa fa-leaf/', '/fa fa-layer-group/', '/fa fa-laugh-wink/', '/fa fa-laugh-wink/', '/fa fa-laugh-squint/', '/fa fa-laugh-squint/', '/fa fa-laugh-beam/', '/fa fa-laugh-beam/', '/fa fa-laugh/', '/fa fa-laugh/', '/fa fa-lastfm-square/', '/fa fa-lastfm/', '/fa fa-laravel/', '/fa fa-laptop-medical/', '/fa fa-laptop-code/', '/fa fa-laptop/', '/fa fa-language/', '/fa fa-landmark/', '/fa fa-krw/', '/fa fa-korvue/', '/fa fa-kiwi-bird/', '/fa fa-kiss-wink-heart/', '/fa fa-kiss-wink-heart/', '/fa fa-kiss-beam/', '/fa fa-kiss-beam/', '/fa fa-kiss/', '/fa fa-kiss/', '/fa fa-kickstarter-k/', '/fa fa-kickstarter/', '/fa fa-khanda/', '/fa fa-keycdn/', '/fa fa-keyboard-o/', '/fa fa-keyboard/', '/fa fa-keybase/', '/fa fa-key/', '/fa fa-kaggle/', '/fa fa-kaaba/', '/fa fa-jsfiddle/', '/fa fa-js-square/', '/fa fa-js/', '/fa fa-journal-whills/', '/fa fa-joomla/', '/fa fa-joint/', '/fa fa-joget/', '/fa fa-jira/', '/fa fa-jenkins/', '/fa fa-jedi-order/', '/fa fa-jedi/', '/fa fa-java/', '/fa fa-itunes-note/', '/fa fa-itunes/', '/fa fa-itch-io/', '/fa fa-italic/', '/fa fa-ioxhost/', '/fa fa-invision/', '/fa fa-intersex/', '/fa fa-internet-explorer/', '/fa fa-intercom/', '/fa fa-instagram/', '/fa fa-inr/', '/fa fa-info-circle/', '/fa fa-info/', '/fa fa-infinity/', '/fa fa-industry/', '/fa fa-indent/', '/fa fa-inbox/', '/fa fa-imdb/', '/fa fa-images/', '/fa fa-images/', '/fa fa-ils/', '/fa fa-igloo/', '/fa fa-id-card-alt/', '/fa fa-id-badge/', '/fa fa-id-badge/', '/fa fa-icons/', '/fa fa-icicles/', '/fa fa-ice-cream/', '/fa fa-i-cursor/', '/fa fa-hubspot/', '/fa fa-html5/', '/fa fa-hryvnia/', '/fa fa-houzz/', '/fa fa-house-damage/', '/fa fa-hourglass-o/', '/fa fa-hourglass-end/', '/fa fa-hourglass-3/', '/fa fa-hourglass-2/', '/fa fa-hourglass-1/', '/fa fa-hourglass/', '/fa fa-hotjar/', '/fa fa-hotel/', '/fa fa-hotel/', '/fa fa-hotdog/', '/fa fa-hot-tub/', '/fa fa-hospital-symbol/', '/fa fa-hospital-o/', '/fa fa-hospital-alt/', '/fa fa-hospital/', '/fa fa-horse-head/', '/fa fa-horse/', '/fa fa-hornbill/', '/fa fa-hooli/', '/fa fa-home/', '/fa fa-holly-berry/', '/fa fa-hockey-puck/', '/fa fa-history/', '/fa fa-hire-a-helper/', '/fa fa-hips/', '/fa fa-hippo/', '/fa fa-hiking/', '/fa fa-highlighter/', '/fa fa-helicopter/', '/fa fa-heartbeat/', '/fa fa-heart-o/', '/fa fa-heart-broken/', '/fa fa-heart/', '/fa fa-headset/', '/fa fa-headphones-alt/', '/fa fa-headphones/', '/fa fa-header/', '/fa fa-hdd-o/', '/fa fa-hdd/', '/fa fa-haykal/', '/fa fa-hat-wizard/', '/fa fa-hashtag/', '/fa fa-hard-hat/', '/fa fa-hanukiah/', '/fa fa-handshake-o/', '/fa fa-handshake/', '/fa fa-hands-helping/', '/fa fa-hands/', '/fa fa-hand-spock-o/', '/fa fa-hand-spock/', '/fa fa-hand-scissors-o/', '/fa fa-hand-scissors/', '/fa fa-hand-rock-o/', '/fa fa-hand-rock/', '/fa fa-hand-pointer-o/', '/fa fa-hand-pointer/', '/fa fa-hand-point-up/', '/fa fa-hand-point-right/', '/fa fa-hand-point-left/', '/fa fa-hand-point-down/', '/fa fa-hand-peace-o/', '/fa fa-hand-peace/', '/fa fa-hand-paper-o/', '/fa fa-hand-paper/', '/fa fa-hand-o-up/', '/fa fa-hand-o-right/', '/fa fa-hand-o-left/', '/fa fa-hand-o-down/', '/fa fa-hand-middle-finger/', '/fa fa-hand-lizard-o/', '/fa fa-hand-lizard/', '/fa fa-hand-holding-usd/', '/fa fa-hand-holding-heart/', '/fa fa-hand-holding/', '/fa fa-hamsa/', '/fa fa-hammer/', '/fa fa-hamburger/', '/fa fa-hackerrank/', '/fa fa-hacker-news-square/', '/fa fa-h-square/', '/fa fa-gulp/', '/fa fa-guitar/', '/fa fa-grunt/', '/fa fa-group/', '/fa fa-gripfire/', '/fa fa-grip-vertical/', '/fa fa-grip-lines-vertical/', '/fa fa-grip-lines/', '/fa fa-grip-horizontal/', '/fa fa-grin-wink/', '/fa fa-grin-wink/', '/fa fa-grin-tongue-wink/', '/fa fa-grin-tongue-wink/', '/fa fa-grin-tongue-squint/', '/fa fa-grin-tongue-squint/', '/fa fa-grin-tongue/', '/fa fa-grin-tongue/', '/fa fa-grin-tears/', '/fa fa-grin-tears/', '/fa fa-grin-stars/', '/fa fa-grin-stars/', '/fa fa-grin-squint-tears/', '/fa fa-grin-squint-tears/', '/fa fa-grin-squint/', '/fa fa-grin-squint/', '/fa fa-grin-hearts/', '/fa fa-grin-hearts/', '/fa fa-grin-beam-sweat/', '/fa fa-grin-beam-sweat/', '/fa fa-grin-beam/', '/fa fa-grin-beam/', '/fa fa-grin-alt/', '/fa fa-grin-alt/', '/fa fa-grin/', '/fa fa-grin/', '/fa fa-grimace/', '/fa fa-grimace/', '/fa fa-greater-than-equal/', '/fa fa-greater-than/', '/fa fa-grav/', '/fa fa-gopuram/', '/fa fa-google-wallet/', '/fa fa-google-plus-square/', '/fa fa-google-plus-official/', '/fa fa-google-plus-circle/', '/fa fa-google-play/', '/fa fa-google-drive/', '/fa fa-google/', '/fa fa-goodreads-g/', '/fa fa-goodreads/', '/fa fa-golf-ball/', '/fa fa-gofore/', '/fa fa-globe-europe/', '/fa fa-globe-asia/', '/fa fa-globe-americas/', '/fa fa-globe-africa/', '/fa fa-globe/', '/fa fa-glide-g/', '/fa fa-glide/', '/fa fa-glasses/', '/fa fa-glass-whiskey/', '/fa fa-glass-martini-alt/', '/fa fa-glass-cheers/', '/fa fa-glass/', '/fa fa-gittip/', '/fa fa-gitter/', '/fa fa-gitlab/', '/fa fa-gitkraken/', '/fa fa-github-square/', '/fa fa-github-alt/', '/fa fa-github/', '/fa fa-git-square/', '/fa fa-git-alt/', '/fa fa-git/', '/fa fa-gifts/', '/fa fa-gift/', '/fa fa-ghost/', '/fa fa-gg-circle/', '/fa fa-gg/', '/fa fa-get-pocket/', '/fa fa-genderless/', '/fa fa-gem/', '/fa fa-gears/', '/fa fa-gear/', '/fa fa-ge/', '/fa fa-gbp/', '/fa fa-gavel/', '/fa fa-gas-pump/', '/fa fa-gamepad/', '/fa fa-galactic-senate/', '/fa fa-galactic-republic/', '/fa fa-futbol-o/', '/fa fa-funnel-dollar/', '/fa fa-fulcrum/', '/fa fa-frown-open/', '/fa fa-frown-open/', '/fa fa-frown-o/', '/fa fa-frown/', '/fa fa-frog/', '/fa fa-freebsd/', '/fa fa-free-code-camp/', '/fa fa-foursquare/', '/fa fa-forward/', '/fa fa-forumbee/', '/fa fa-fort-awesome-alt/', '/fa fa-fort-awesome/', '/fa fa-football-ball/', '/fa fa-fonticons-fi/', '/fa fa-fonticons/', '/fa fa-font-awesome-flag/', '/fa fa-font-awesome-alt/', '/fa fa-font/', '/fa fa-folder-plus/', '/fa fa-folder-open-o/', '/fa fa-folder-open/', '/fa fa-folder-o/', '/fa fa-folder-minus/', '/fa fa-folder/', '/fa fa-fly/', '/fa fa-flushed/', '/fa fa-flushed/', '/fa fa-floppy-o/', '/fa fa-flipboard/', '/fa fa-flickr/', '/fa fa-flask/', '/fa fa-flash/', '/fa fa-flag-usa/', '/fa fa-flag-o/', '/fa fa-flag-checkered/', '/fa fa-flag/', '/fa fa-fist-raised/', '/fa fa-fish/', '/fa fa-firstdraft/', '/fa fa-first-order-alt/', '/fa fa-first-order/', '/fa fa-first-aid/', '/fa fa-firefox/', '/fa fa-fire-extinguisher/', '/fa fa-fire-alt/', '/fa fa-fire/', '/fa fa-fingerprint/', '/fa fa-filter/', '/fa fa-film/', '/fa fa-fill-drip/', '/fa fa-fill/', '/fa fa-files-o/', '/fa fa-file-word-o/', '/fa fa-file-word/', '/fa fa-file-video-o/', '/fa fa-file-video/', '/fa fa-file-upload/', '/fa fa-file-text-o/', '/fa fa-file-text/', '/fa fa-file-signature/', '/fa fa-file-prescription/', '/fa fa-file-powerpoint-o/', '/fa fa-file-powerpoint/', '/fa fa-file-photo-o/', '/fa fa-file-pdf-o/', '/fa fa-file-pdf/', '/fa fa-file-o/', '/fa fa-file-medical-alt/', '/fa fa-file-medical/', '/fa fa-file-invoice-dollar/', '/fa fa-file-invoice/', '/fa fa-file-import/', '/fa fa-file-image-o/', '/fa fa-file-export/', '/fa fa-file-excel-o/', '/fa fa-file-excel/', '/fa fa-file-download/', '/fa fa-file-csv/', '/fa fa-file-contract/', '/fa fa-file-code-o/', '/fa fa-file-code/', '/fa fa-file-audio-o/', '/fa fa-file-audio/', '/fa fa-file-archive-o/', '/fa fa-file-archive/', '/fa fa-file/', '/fa fa-figma/', '/fa fa-fighter-jet/', '/fa fa-female/', '/fa fa-feed/', '/fa fa-fedora/', '/fa fa-fedex/', '/fa fa-feather-alt/', '/fa fa-feather/', '/fa fa-fax/', '/fa fa-fast-forward/', '/fa fa-fast-backward/', '/fa fa-fantasy-flight-games/', '/fa fa-fan/', '/fa fa-facebook-square/', '/fa fa-facebook-official/', '/fa fa-facebook-messenger/', '/fa fa-facebook/', '/fa fa-fa/', '/fa fa-eye-slash/', '/fa fa-eye-slash/', '/fa fa-eye-dropper/', '/fa fa-eye/', '/fa fa-eye/', '/fa fa-external-link-square/', '/fa fa-external-link/', '/fa fa-expeditedssl/', '/fa fa-expand/', '/fa fa-exclamation-circle/', '/fa fa-exclamation/', '/fa fa-exchange/', '/fa fa-evernote/', '/fa fa-euro/', '/fa fa-etsy/', '/fa fa-ethernet/', '/fa fa-ethereum/', '/fa fa-erlang/', '/fa fa-eraser/', '/fa fa-equals/', '/fa fa-envira/', '/fa fa-envelope-square/', '/fa fa-envelope-open-text/', '/fa fa-envelope-open-o/', '/fa fa-envelope-open/', '/fa fa-envelope-o/', '/fa fa-envelope/', '/fa fa-envelope/', '/fa fa-ember/', '/fa fa-ello/', '/fa fa-ellipsis-v/', '/fa fa-ellipsis-h/', '/fa fa-elementor/', '/fa fa-eject/', '/fa fa-egg/', '/fa fa-eercast/', '/fa fa-edit/', '/fa fa-edge/', '/fa fa-ebay/', '/fa fa-earlybirds/', '/fa fa-dyalog/', '/fa fa-dungeon/', '/fa fa-dumpster-fire/', '/fa fa-dumpster/', '/fa fa-dumbbell/', '/fa fa-drupal/', '/fa fa-drumstick-bite/', '/fa fa-drum-steelpan/', '/fa fa-drum/', '/fa fa-dropbox/', '/fa fa-drivers-license-o/', '/fa fa-drivers-license/', '/fa fa-dribbble-square/', '/fa fa-dribbble/', '/fa fa-draw-polygon/', '/fa fa-dragon/', '/fa fa-drafting-compass/', '/fa fa-draft2digital/', '/fa fa-download/', '/fa fa-dove/', '/fa fa-dot-circle-o/', '/fa fa-dot-circle/', '/fa fa-door-open/', '/fa fa-door-closed/', '/fa fa-donate/', '/fa fa-dolly-flatbed/', '/fa fa-dolly/', '/fa fa-dollar/', '/fa fa-dog/', '/fa fa-docker/', '/fa fa-dochub/', '/fa fa-dna/', '/fa fa-dizzy/', '/fa fa-dizzy/', '/fa fa-divide/', '/fa fa-discourse/', '/fa fa-discord/', '/fa fa-directions/', '/fa fa-digital-tachograph/', '/fa fa-digital-ocean/', '/fa fa-digg/', '/fa fa-dice-two/', '/fa fa-dice-three/', '/fa fa-dice-six/', '/fa fa-dice-one/', '/fa fa-dice-four/', '/fa fa-dice-five/', '/fa fa-dice-d6/', '/fa fa-dice-d20/', '/fa fa-dice/', '/fa fa-diaspora/', '/fa fa-diamond/', '/fa fa-diagnoses/', '/fa fa-dhl/', '/fa fa-dharmachakra/', '/fa fa-deviantart/', '/fa fa-dev/', '/fa fa-desktop/', '/fa fa-deskpro/', '/fa fa-deploydog/', '/fa fa-democrat/', '/fa fa-delicious/', '/fa fa-dedent/', '/fa fa-deafness/', '/fa fa-database/', '/fa fa-dashcube/', '/fa fa-dashboard/', '/fa fa-d-and-d-beyond/', '/fa fa-d-and-d/', '/fa fa-cuttlefish/', '/fa fa-cutlery/', '/fa fa-cubes/', '/fa fa-cube/', '/fa fa-css3-alt/', '/fa fa-css3/', '/fa fa-crutch/', '/fa fa-crown/', '/fa fa-crow/', '/fa fa-crosshairs/', '/fa fa-cross/', '/fa fa-crop-alt/', '/fa fa-crop/', '/fa fa-critical-role/', '/fa fa-credit-card/', '/fa fa-credit-card/', '/fa fa-creative-commons-zero/', '/fa fa-creative-commons-share/', '/fa fa-creative-commons-sampling-plus/', '/fa fa-creative-commons-sampling/', '/fa fa-creative-commons-sa/', '/fa fa-creative-commons-remix/', '/fa fa-creative-commons-pd-alt/', '/fa fa-creative-commons-pd/', '/fa fa-creative-commons-nd/', '/fa fa-creative-commons-nc-jp/', '/fa fa-creative-commons-nc-eu/', '/fa fa-creative-commons-nc/', '/fa fa-creative-commons-by/', '/fa fa-creative-commons/', '/fa fa-cpanel/', '/fa fa-couch/', '/fa fa-cotton-bureau/', '/fa fa-copyright/', '/fa fa-copyright/', '/fa fa-copy/', '/fa fa-cookie-bite/', '/fa fa-cookie/', '/fa fa-contao/', '/fa fa-connectdevelop/', '/fa fa-confluence/', '/fa fa-concierge-bell/', '/fa fa-compress-arrows-alt/', '/fa fa-compress/', '/fa fa-compass/', '/fa fa-compass/', '/fa fa-compact-disc/', '/fa fa-comments-o/', '/fa fa-comments-dollar/', '/fa fa-comments/', '/fa fa-commenting-o/', '/fa fa-commenting/', '/fa fa-comment-slash/', '/fa fa-comment-o/', '/fa fa-comment-medical/', '/fa fa-comment-dollar/', '/fa fa-comment-alt/', '/fa fa-comment-alt/', '/fa fa-comment/', '/fa fa-columns/', '/fa fa-coins/', '/fa fa-coffee/', '/fa fa-codiepie/', '/fa fa-codepen/', '/fa fa-code-fork/', '/fa fa-code/', '/fa fa-cocktail/', '/fa fa-cny/', '/fa fa-cloudversify/', '/fa fa-cloudsmith/', '/fa fa-cloudscale/', '/fa fa-cloud-upload/', '/fa fa-cloud-sun-rain/', '/fa fa-cloud-sun/', '/fa fa-cloud-showers-heavy/', '/fa fa-cloud-rain/', '/fa fa-cloud-moon-rain/', '/fa fa-cloud-moon/', '/fa fa-cloud-meatball/', '/fa fa-cloud-download/', '/fa fa-cloud/', '/fa fa-closed-captioning/', '/fa fa-close/', '/fa fa-clone/', '/fa fa-clone/', '/fa fa-clock-o/', '/fa fa-clock/', '/fa fa-clipboard-list/', '/fa fa-clipboard-check/', '/fa fa-clipboard/', '/fa fa-clinic-medical/', '/fa fa-city/', '/fa fa-circle-o-notch/', '/fa fa-circle-o/', '/fa fa-circle/', '/fa fa-church/', '/fa fa-chromecast/', '/fa fa-chrome/', '/fa fa-child/', '/fa fa-chevron-up/', '/fa fa-chevron-right/', '/fa fa-chevron-left/', '/fa fa-chevron-down/', '/fa fa-chevron-circle-up/', '/fa fa-chevron-circle-right/', '/fa fa-chevron-circle-left/', '/fa fa-chevron-circle-down/', '/fa fa-chess-rook/', '/fa fa-chess-queen/', '/fa fa-chess-pawn/', '/fa fa-chess-knight/', '/fa fa-chess-king/', '/fa fa-chess-board/', '/fa fa-chess-bishop/', '/fa fa-chess/', '/fa fa-cheese/', '/fa fa-check-square-o/', '/fa fa-check-square/', '/fa fa-check-double/', '/fa fa-check-circle-o/', '/fa fa-check-circle/', '/fa fa-check/', '/fa fa-chart-line/', '/fa fa-chart-area/', '/fa fa-charging-station/', '/fa fa-chalkboard-teacher/', '/fa fa-chalkboard/', '/fa fa-chair/', '/fa fa-chain-broken/', '/fa fa-chain/', '/fa fa-certificate/', '/fa fa-centos/', '/fa fa-centercode/', '/fa fa-cc-visa/', '/fa fa-cc-stripe/', '/fa fa-cc-paypal/', '/fa fa-cc-mastercard/', '/fa fa-cc-jcb/', '/fa fa-cc-discover/', '/fa fa-cc-diners-club/', '/fa fa-cc-apple-pay/', '/fa fa-cc-amex/', '/fa fa-cc-amazon-pay/', '/fa fa-cc/', '/fa fa-cat/', '/fa fa-cash-register/', '/fa fa-cart-plus/', '/fa fa-cart-arrow-down/', '/fa fa-carrot/', '/fa fa-caret-up/', '/fa fa-caret-square-o-up/', '/fa fa-caret-square-o-right/', '/fa fa-caret-square-o-left/', '/fa fa-caret-square-o-down/', '/fa fa-caret-right/', '/fa fa-caret-left/', '/fa fa-caret-down/', '/fa fa-car-side/', '/fa fa-car-crash/', '/fa fa-car-battery/', '/fa fa-car-alt/', '/fa fa-car/', '/fa fa-capsules/', '/fa fa-cannabis/', '/fa fa-candy-cane/', '/fa fa-canadian-maple-leaf/', '/fa fa-campground/', '/fa fa-camera-retro/', '/fa fa-camera/', '/fa fa-calendar-week/', '/fa fa-calendar-times-o/', '/fa fa-calendar-times/', '/fa fa-calendar-plus-o/', '/fa fa-calendar-plus/', '/fa fa-calendar-o/', '/fa fa-calendar-minus/', '/fa fa-calendar-minus/', '/fa fa-calendar-day/', '/fa fa-calendar-check-o/', '/fa fa-calendar-check/', '/fa fa-calendar-alt/', '/fa fa-calendar/', '/fa fa-calendar/', '/fa fa-calculator/', '/fa fa-cab/', '/fa fa-buysellads/', '/fa fa-business-time/', '/fa fa-bus-alt/', '/fa fa-bus/', '/fa fa-buromobelexperte/', '/fa fa-burn/', '/fa fa-bullseye/', '/fa fa-bullhorn/', '/fa fa-building-o/', '/fa fa-building/', '/fa fa-bug/', '/fa fa-buffer/', '/fa fa-brush/', '/fa fa-broom/', '/fa fa-broadcast-tower/', '/fa fa-briefcase-medical/', '/fa fa-briefcase/', '/fa fa-bread-slice/', '/fa fa-brain/', '/fa fa-braille/', '/fa fa-boxes/', '/fa fa-box-open/', '/fa fa-box/', '/fa fa-bowling-ball/', '/fa fa-border-style/', '/fa fa-border-none/', '/fa fa-border-all/', '/fa fa-bootstrap/', '/fa fa-bookmark-o/', '/fa fa-bookmark/', '/fa fa-book-reader/', '/fa fa-book-open/', '/fa fa-book-medical/', '/fa fa-book-dead/', '/fa fa-book/', '/fa fa-bong/', '/fa fa-bone/', '/fa fa-bomb/', '/fa fa-bold/', '/fa fa-bluetooth-b/', '/fa fa-bluetooth/', '/fa fa-blogger-b/', '/fa fa-blogger/', '/fa fa-blog/', '/fa fa-blind/', '/fa fa-blender-phone/', '/fa fa-blender/', '/fa fa-blackberry/', '/fa fa-black-tie/', '/fa fa-bity/', '/fa fa-bitcoin/', '/fa fa-bitcoin/', '/fa fa-bitbucket/', '/fa fa-birthday-cake/', '/fa fa-biohazard/', '/fa fa-binoculars/', '/fa fa-bimobject/', '/fa fa-biking/', '/fa fa-bicycle/', '/fa fa-bible/', '/fa fa-bezier-curve/', '/fa fa-bell-slash-o/', '/fa fa-bell-slash/', '/fa fa-bell-o/', '/fa fa-bell/', '/fa fa-behance-square/', '/fa fa-behance/', '/fa fa-beer/', '/fa fa-battle-net/', '/fa fa-battery-3/', '/fa fa-battery-2/', '/fa fa-battery-1/', '/fa fa-battery-0/', '/fa fa-battery/', '/fa fa-bathtub/', '/fa fa-basketball-ball/', '/fa fa-baseball-ball/', '/fa fa-barcode/', '/fa fa-bar-chart-o/', '/fa fa-bar-chart/', '/fa fa-bank/', '/fa fa-bandcamp/', '/fa fa-band-aid/', '/fa fa-ban/', '/fa fa-balance-scale-right/', '/fa fa-balance-scale-left/', '/fa fa-balance-scale/', '/fa fa-bacon/', '/fa fa-backward/', '/fa fa-backspace/', '/fa fa-baby-carriage/', '/fa fa-baby/', '/fa fa-aws/', '/fa fa-award/', '/fa fa-aviato/', '/fa fa-avianex/', '/fa fa-autoprefixer/', '/fa fa-audio-description/', '/fa fa-audible/', '/fa fa-atom/', '/fa fa-atlassian/', '/fa fa-atlas/', '/fa fa-at/', '/fa fa-asymmetrik/', '/fa fa-asterisk/', '/fa fa-assistive-listening-systems/', '/fa fa-asl-interpreting/', '/fa fa-artstation/', '/fa fa-arrows-v/', '/fa fa-arrows-h/', '/fa fa-arrows-alt/', '/fa fa-arrows/', '/fa fa-arrow-up/', '/fa fa-arrow-right/', '/fa fa-arrow-left/', '/fa fa-arrow-down/', '/fa fa-arrow-circle-up/', '/fa fa-arrow-circle-right/', '/fa fa-arrow-circle-o-up/', '/fa fa-arrow-circle-o-right/', '/fa fa-arrow-circle-o-left/', '/fa fa-arrow-circle-o-down/', '/fa fa-arrow-circle-left/', '/fa fa-arrow-circle-down/', '/fa fa-arrow-alt-circle-up/', '/fa fa-arrow-alt-circle-right/', '/fa fa-arrow-alt-circle-left/', '/fa fa-arrow-alt-circle-down/', '/fa fa-archway/', '/fa fa-archive/', '/fa fa-apple-pay/', '/fa fa-apple-alt/', '/fa fa-apple/', '/fa fa-apper/', '/fa fa-app-store-ios/', '/fa fa-app-store/', '/fa fa-ankh/', '/fa fa-angular/', '/fa fa-angrycreative/', '/fa fa-angry/', '/fa fa-angry/', '/fa fa-angle-up/', '/fa fa-angle-right/', '/fa fa-angle-left/', '/fa fa-angle-down/', '/fa fa-angle-double-up/', '/fa fa-angle-double-right/', '/fa fa-angle-double-left/', '/fa fa-angle-double-down/', '/fa fa-angellist/', '/fa fa-android/', '/fa fa-anchor/', '/fa fa-amilia/', '/fa fa-ambulance/', '/fa fa-amazon-pay/', '/fa fa-amazon/', '/fa fa-allergies/', '/fa fa-alipay/', '/fa fa-align-right/', '/fa fa-align-left/', '/fa fa-align-justify/', '/fa fa-align-center/', '/fa fa-algolia/', '/fa fa-airbnb/', '/fa fa-air-freshener/', '/fa fa-affiliatetheme/', '/fa fa-adversal/', '/fa fa-adobe/', '/fa fa-adn/', '/fa fa-adjust/', '/fa fa-address-card-o/', '/fa fa-address-book-o/', '/fa fa-address-book/', '/fa fa-ad/', '/fa fa-acquisitions-incorporated/', '/fa fa-accusoft/', '/fa fa-500px/'
		);
		return $replace_to;
	}

	/**
	 * FontAwesome 5 Icon class list
	 * @since v 1.2.1
	 */
	public function font_awesome_5_icon_class_list(){
		$replace_by = array(
			'fab fa-zhihu', 'fab fa-youtube-square', 'fab fa-youtube', 'fab fa-yoast', 'fas fa-yin-yang', 'fab fa-yelp', 'fab fa-y-combinator', 'fab fa-yarn', 'fab fa-yandex-international', 'fab fa-yandex', 'fab fa-yammer', 'fab fa-yahoo', 'fab fa-hacker-news', 'fab fa-xing-square', 'fab fa-xing', 'fab fa-xbox', 'fas fa-x-ray', 'fas fa-wrench', 'fab fa-wpressr', 'fab fa-wpforms', 'fab fa-wpexplorer', 'fab fa-wpbeginner', 'fab fa-wordpress-simple', 'fab fa-wordpress', 'fab fa-wolf-pack-battalion', 'fab fa-wizards-of-the-coast', 'fab fa-wix', 'fas fa-wine-glass-alt', 'fas fa-wine-glass', 'fas fa-wine-bottle', 'fab fa-windows', 'fas fa-window-restore', 'fas fa-window-restore', 'fas fa-window-minimize', 'fas fa-window-minimize', 'fas fa-window-maximize', 'fas fa-window-maximize', 'fas fa-wind', 'fab fa-wikipedia-w', 'fas fa-wifi', 'fab fa-whmcs', 'fab fa-accessible-icon', 'fas fa-wheelchair', 'fab fa-whatsapp-square', 'fab fa-whatsapp', 'fas fa-weight-hanging', 'fas fa-weight', 'fab fa-weibo', 'fab fa-weebly', 'fab fa-weixin', 'fab fa-waze', 'fas fa-wave-square', 'fas fa-water', 'fas fa-exclamation-triangle', 'fas fa-warehouse', 'fas fa-wallet', 'fas fa-walking', 'fab fa-vuejs', 'fas fa-vr-cardboard', 'fas fa-vote-yea', 'fas fa-volume-up', 'fas fa-volume-off', 'fas fa-volume-mute', 'fas fa-volume-down', 'fas fa-phone-volume', 'fas fa-volleyball-ball', 'fas fa-voicemail', 'fab fa-vnv', 'fab fa-vk', 'fab fa-vine', 'fab fa-vimeo-square', 'fab fa-vimeo', 'fab fa-vimeo', 'fas fa-vihara', 'fas fa-video-slash', 'fas fa-video', 'fab fa-viber', 'fas fa-vials', 'fas fa-vial', 'fab fa-viadeo-square', 'fab fa-viadeo', 'fab fa-viacoin', 'fas fa-venus-mars', 'fas fa-venus-double', 'fas fa-venus', 'fas fa-vector-square', 'far fa-address-card', 'fab fa-vaadin', 'fab fa-ussunnah', 'fab fa-usps', 'fas fa-users-cog', 'fas fa-user', 'fas fa-user-tie', 'fas fa-user-tag', 'fas fa-user-slash', 'fas fa-user-shield', 'fas fa-user-secret', 'fas fa-user-plus', 'fas fa-user', 'fas fa-user-nurse', 'fas fa-user-ninja', 'fas fa-user-minus', 'fas fa-user-md', 'fas fa-user-lock', 'fas fa-user-injured', 'fas fa-user-graduate', 'fas fa-user-friends', 'fas fa-user-edit', 'fas fa-user-cog', 'fas fa-user-clock', 'fas fa-user-circle', 'far fa-user-circle', 'fas fa-user-check', 'fas fa-user-astronaut', 'fas fa-user-alt-slash', 'fas fa-user-alt', 'far fa-user', 'fab fa-usb', 'fab fa-ups', 'fas fa-upload', 'fab fa-untappd', 'fas fa-sort', 'fas fa-unlock-alt', 'fas fa-unlock', 'fas fa-universal-access', 'fab fa-uniregistry', 'fas fa-undo-alt', 'fas fa-underline', 'fas fa-umbrella-beach', 'fas fa-umbrella', 'fab fa-uikit', 'fab fa-ubuntu', 'fab fa-uber', 'fab fa-typo3', 'fab fa-twitter-square', 'fab fa-twitter', 'fab fa-twitch', 'fab fa-tumblr-square', 'fab fa-tumblr', 'fas fa-tty', 'fas fa-tshirt', 'fas fa-lira-sign', 'fas fa-truck-pickup', 'fas fa-truck-moving', 'fas fa-truck-monster', 'fas fa-truck-loading', 'fas fa-truck', 'fas fa-trophy', 'fab fa-tripadvisor', 'fab fa-trello', 'fas fa-tree', 'fas fa-trash-restore-alt', 'fas fa-trash-restore', 'fas fa-trash', 'fas fa-trash-alt', 'fas fa-trash-alt', 'fas fa-transgender-alt', 'fas fa-tram', 'fas fa-train', 'fas fa-traffic-light', 'fas fa-trademark', 'fab fa-trade-federation', 'fas fa-tractor', 'fas fa-torii-gate', 'fas fa-torah', 'fas fa-tooth', 'fas fa-tools', 'fas fa-toolbox', 'fas fa-toilet-paper', 'fas fa-toilet', 'far fa-caret-square-up', 'far fa-caret-square-right', 'fas fa-toggle-on', 'fas fa-toggle-off', 'far fa-caret-square-left', 'far fa-caret-square-down', 'fas fa-tired', 'fas fa-tired', 'fas fa-tint-slash', 'fas fa-tint', 'fas fa-window-close-o', 'far fa-window-close', 'fas fa-times-circle', 'far fa-times-circle', 'fas fa-ticket-alt', 'fas fa-thumbs-up', 'far fa-thumbs-up', 'far fa-thumbs-down', 'fas fa-thumbs-down', 'fas fa-thumbtack', 'fab fa-think-peaks', 'fas fa-thermometer-three-quarters', 'fas fa-thermometer-half', 'fas fa-thermometer-quarter', 'fas fa-thermometer-empty', 'fas fa-thermometer', 'fas fa-thermometer', 'fab fa-themeisle', 'fab fa-themeco', 'fas fa-theater-masks', 'fab fa-the-red-yeti', 'fas fa-th-list', 'fas fa-th-large', 'fas fa-th', 'fas fa-text-width', 'fas fa-text-height', 'fas fa-terminal', 'fas fa-tenge', 'fab fa-tencent-weibo', 'fas fa-temperature-low', 'fas fa-temperature-high', 'fas fa-tv', 'fab fa-telegram-plane', 'fab fa-telegram', 'fas fa-teeth-open', 'fas fa-teeth', 'fab fa-teamspeak', 'fas fa-tasks', 'fas fa-tape', 'fas fa-tags', 'fas fa-tag', 'fas fa-tablets', 'fas fa-tablet', 'fas fa-tablet', 'fas fa-table-tennis', 'fas fa-table', 'fas fa-syringe', 'fas fa-sync-alt', 'fas fa-synagogue', 'fab fa-symfony', 'fas fa-swimming-pool', 'fas fa-swimmer', 'fas fa-swatchbook', 'fab fa-suse', 'fas fa-surprise', 'fas fa-surprise', 'fab fa-supple', 'fas fa-superscript', 'fab fa-superpowers', 'fas fa-sun', 'far fa-sun', 'fas fa-suitcase-rolling', 'fas fa-suitcase', 'fas fa-subway', 'fas fa-subscript', 'fab fa-stumbleupon-circle', 'fab fa-stumbleupon', 'fab fa-studiovinari', 'fas fa-stroopwafel', 'fab fa-stripe-s', 'fab fa-stripe', 'fas fa-strikethrough', 'fas fa-street-view', 'fas fa-stream', 'fab fa-strava', 'fas fa-store-alt', 'fas fa-store', 'fas fa-stopwatch', 'fas fa-stop-circle', 'far fa-stop-circle', 'fas fa-stop', 'fas fa-sticky-note', 'far fa-sticky-note', 'fab fa-sticker-mule', 'fas fa-stethoscope', 'fas fa-step-forward', 'fas fa-step-backward', 'fab fa-steam-symbol', 'fab fa-steam-square', 'fab fa-steam', 'fab fa-staylinked', 'fas fa-star-of-life', 'fas fa-star-of-david', 'fas fa-star', 'far fa-star-half', 'fas fa-star-half-alt', 'fas fa-star-half', 'fas fa-star-and-crescent', 'far fa-star', 'fas fa-stamp', 'fab fa-stackpath', 'fab fa-stack-overflow', 'fab fa-stack-exchange', 'fab fa-squarespace', 'fas fa-square-root-alt', 'fas fa-square-full', 'fas fa-square', 'fas fa-square', 'fas fa-spray-can', 'fab fa-spotify', 'fas fa-utensil-spoon', 'fas fa-splotch', 'fas fa-spinner', 'fas fa-spider', 'fas fa-spell-check', 'fab fa-speaker-deck', 'fab fa-speakap', 'fas fa-space-shuttle', 'fas fa-spa', 'fab fa-sourcetree', 'fab fa-soundcloud', 'fas fa-sort-numeric-up-alt', 'fas fa-sort-numeric-down-alt', 'fas fa-sort-numeric-up', 'fas fa-sort-numeric-down', 'fas fa-sort-down', 'fas fa-sort-up', 'fas fa-sort-amount-up-alt', 'fas fa-sort-amount-down-alt', 'fas fa-sort-amount-up', 'fas fa-sort-amount-down', 'fas fa-sort-alpha-up-alt', 'fas fa-sort-alpha-down-alt', 'fas fa-sort-alpha-up', 'fas fa-sort-alpha-down', 'fas fa-solar-panel', 'fas fa-socks', 'far fa-futbol', 'fas fa-snowplow', 'fas fa-snowman', 'fas fa-snowflake', 'far fa-snowflake', 'fas fa-snowboarding', 'fab fa-snapchat-square', 'fab fa-snapchat-ghost', 'fab fa-snapchat', 'fas fa-sms', 'fas fa-smoking-ban', 'fas fa-smoking', 'fas fa-smog', 'fas fa-smile-wink', 'fas fa-smile-wink', 'fas fa-smile', 'fas fa-smile-beam', 'fas fa-smile-beam', 'far fa-smile', 'fab fa-slideshare', 'fas fa-sliders-h', 'fas fa-sleigh', 'fas fa-slash', 'fab fa-slack-hash', 'fab fa-slack', 'fab fa-skype', 'fab fa-skyatlas', 'fas fa-skull-crossbones', 'fas fa-skull', 'fas fa-skiing-nordic', 'fas fa-skiing', 'fab fa-sketch', 'fas fa-skating', 'fab fa-sith', 'fas fa-sitemap', 'fab fa-sistrix', 'fab fa-simplybuilt', 'fas fa-sim-card', 'fas fa-sign-language', 'fas fa-signature', 'fas fa-signal', 'fas fa-sign-out-alt', 'fas fa-sign-in-alt', 'fas fa-sign', 'fas fa-shuttle-van', 'fas fa-shower', 'fab fa-shopware', 'fas fa-shopping-cart', 'fas fa-shopping-basket', 'fas fa-shopping-bag', 'fas fa-shoe-prints', 'fab fa-shirtsinbulk', 'fas fa-shipping-fast', 'fas fa-ship', 'fas fa-shield-alt', 'fas fa-share-square', 'far fa-share-square', 'fas fa-share-alt-square', 'fas fa-share-alt', 'fas fa-shapes', 'fab fa-servicestack', 'fas fa-server', 'far fa-paper-plane', 'fab fa-sellsy', 'fas fa-seedling', 'fab fa-searchengin', 'fas fa-search-plus', 'fas fa-search-minus', 'fas fa-search-location', 'fas fa-search-dollar', 'fas fa-search', 'fas fa-sd-card', 'fas fa-scroll', 'fab fa-scribd', 'fas fa-screwdriver', 'fas fa-cut', 'fas fa-school', 'fab fa-schlix', 'far fa-save', 'fas fa-satellite-dish', 'fas fa-satellite', 'fab fa-sass', 'fab fa-salesforce', 'fab fa-safari', 'fas fa-sad-tear', 'fas fa-sad-tear', 'fas fa-sad-cry', 'fas fa-sad-cry', 'fas fa-running', 'fas fa-ruler-vertical', 'fas fa-ruler-horizontal', 'fas fa-ruler-combined', 'fas fa-ruler', 'fas fa-ruble-sign', 'fas fa-rss-square', 'fas fa-route', 'fas fa-undo', 'fab fa-rockrms', 'fab fa-rocketchat', 'fas fa-rocket', 'fas fa-robot', 'fas fa-road', 'fas fa-ring', 'fas fa-ribbon', 'fab fa-rev', 'fas fa-retweet', 'fas fa-restroom', 'fab fa-resolving', 'fab fa-researchgate', 'fas fa-republican', 'fab fa-replyd', 'fas fa-redo', 'fab fa-renren', 'fas fa-remove-format', 'fas fa-registered', 'fas fa-registered', 'fas fa-sync', 'fas fa-redo-alt', 'fab fa-redhat', 'fab fa-reddit-square', 'fab fa-reddit-alien', 'fab fa-reddit', 'fab fa-red-river', 'fas fa-recycle', 'fas fa-receipt', 'fab fa-readme', 'fab fa-reacteurope', 'fab fa-react', 'fab fa-ravelry', 'fab fa-raspberry-pi', 'fas fa-random', 'fas fa-rainbow', 'fas fa-radiation-alt', 'fas fa-radiation', 'fab fa-rebel', 'fab fa-r-project', 'fas fa-quran', 'fas fa-quote-right', 'fas fa-quote-left', 'fab fa-quora', 'fab fa-quinscape', 'fas fa-quidditch', 'fas fa-question-circle', 'far fa-question-circle', 'fas fa-question', 'fas fa-qrcode', 'fab fa-qq', 'fab fa-python', 'fas fa-puzzle-piece', 'fab fa-pushed', 'fas fa-project-diagram', 'fab fa-product-hunt', 'fas fa-procedures', 'fas fa-print', 'fas fa-prescription-bottle-alt', 'fas fa-prescription-bottle', 'fas fa-prescription', 'fas fa-praying-hands', 'fas fa-pray', 'fas fa-power-off', 'fas fa-portrait', 'fas fa-poop', 'fas fa-poo-storm', 'fas fa-poo', 'fas fa-poll-h', 'fas fa-poll', 'fas fa-podcast', 'fas fa-plus-square', 'far fa-plus-square', 'fas fa-plus-circle', 'fas fa-plus', 'fas fa-plug', 'fab fa-playstation', 'fas fa-play-circle', 'far fa-play-circle', 'fas fa-play', 'fas fa-plane-departure', 'fas fa-plane-arrival', 'fas fa-plane', 'fas fa-place-of-worship', 'fas fa-pizza-slice', 'fab fa-pinterest-square', 'fab fa-pinterest-p', 'fab fa-pinterest', 'fas fa-pills', 'fas fa-piggy-bank', 'fab fa-pied-piper-pp', 'fab fa-pied-piper-hat', 'fab fa-pied-piper-alt', 'fab fa-pied-piper', 'fas fa-chart-pie', 'fas fa-image', 'fab fa-php', 'fas fa-photo-video', 'far fa-image', 'fas fa-phone-square-alt', 'fas fa-phone-square', 'fas fa-phone-slash', 'fas fa-phone-alt', 'fas fa-phone', 'fab fa-phoenix-squadron', 'fab fa-phoenix-framework', 'fab fa-phabricator', 'fas fa-person-booth', 'fab fa-periscope', 'fas fa-percentage', 'fas fa-percent', 'fas fa-pepper-hot', 'fas fa-people-carry', 'fab fa-penny-arcade', 'far fa-edit', 'fas fa-pencil-ruler', 'fas fa-pencil-alt', 'fas fa-pen-square', 'fas fa-pen-nib', 'fas fa-pen-fancy', 'fas fa-pen-alt', 'fas fa-pen', 'fas fa-peace', 'fab fa-paypal', 'fas fa-paw', 'fas fa-pause-circle', 'far fa-pause-circle', 'fas fa-pause', 'fab fa-patreon', 'fas fa-paste', 'fas fa-paste', 'fas fa-pastafasianism', 'fas fa-passport', 'fas fa-parking', 'fas fa-paragraph', 'fas fa-parachute-box', 'fas fa-paperclip', 'fas fa-paper-plane', 'fas fa-pallet', 'fab fa-palfed', 'fas fa-palette', 'fas fa-paint-roller', 'fas fa-paint-brush', 'fas fa-pager', 'fab fa-pagelines', 'fab fa-page4', 'fas fa-otter', 'fab fa-osi', 'fab fa-optin-monster', 'fab fa-opera', 'fab fa-openid', 'fab fa-opencart', 'fas fa-om', 'fab fa-old-republic', 'fas fa-oil-can', 'fab fa-odnoklassniki-square', 'fab fa-odnoklassniki', 'fas fa-object-ungroup', 'fas fa-object-ungroup', 'fas fa-object-group', 'fas fa-object-group', 'fab fa-nutritionix', 'fab fa-ns8', 'fab fa-npm', 'fas fa-notes-medical', 'fas fa-not-equal', 'fab fa-node-js', 'fab fa-node', 'fab fa-nimblr', 'fas fa-newspaper', 'far fa-newspaper', 'fas fa-neuter', 'fas fa-network-wired', 'fab fa-neos', 'fas fa-bars', 'fab fa-napster', 'fas fa-music', 'fas fa-mug-hot', 'fas fa-mouse-pointer', 'fas fa-mountain', 'fas fa-motorcycle', 'fas fa-mosque', 'fas fa-mortar-pestle', 'fas fa-graduation-cap', 'fas fa-moon', 'far fa-moon', 'fas fa-monument', 'fas fa-money-check-alt', 'fas fa-money-check', 'fas fa-money-bill-wave-alt', 'fas fa-money-bill-wave', 'far fa-money-bill-alt', 'fas fa-money-bill', 'fas fa-money-bill-alt', 'fab fa-monero', 'fab fa-modx', 'fas fa-mobile', 'fas fa-mobile', 'fab fa-mizuni', 'fab fa-mixcloud', 'fab fa-mix', 'fas fa-mitten', 'fas fa-minus-square', 'far fa-minus-square', 'fas fa-minus-circle', 'fas fa-minus', 'fab fa-microsoft', 'fas fa-microscope', 'fas fa-microphone-slash', 'fas fa-microphone-alt-slash', 'fas fa-microphone-alt', 'fas fa-microphone', 'fas fa-microchip', 'fas fa-meteor', 'fas fa-mercury', 'fas fa-menorah', 'fab fa-mendeley', 'fas fa-memory', 'fas fa-meh-rolling-eyes', 'fas fa-meh-rolling-eyes', 'fas fa-meh', 'fas fa-meh-blank', 'fas fa-meh-blank', 'far fa-meh', 'fab fa-megaport', 'fab fa-meetup', 'fab fa-medrt', 'fas fa-medkit', 'fab fa-medium-m', 'fab fa-medium', 'fab fa-medapps', 'fas fa-medal', 'fab fa-maxcdn', 'fab fa-mastodon', 'fas fa-mask', 'fas fa-mars-stroke-v', 'fas fa-mars-stroke-h', 'fas fa-mars-stroke', 'fas fa-mars-double', 'fas fa-mars', 'fas fa-marker', 'fab fa-markdown', 'fas fa-map-signs', 'fas fa-map-pin', 'fas fa-map', 'fas fa-map-marker', 'fas fa-map-marker', 'fas fa-map-marked-alt', 'fas fa-map-marked', 'far fa-map', 'fab fa-mandalorian', 'fas fa-male', 'fab fa-mailchimp', 'fas fa-reply-all', 'fas fa-reply', 'fas fa-share', 'fas fa-mail-bulk', 'fas fa-magnet', 'fas fa-magic', 'fab fa-magento', 'fab fa-lyft', 'fas fa-luggage-cart', 'fas fa-low-vision', 'fas fa-long-arrow-alt-up', 'fas fa-long-arrow-alt-right', 'fas fa-long-arrow-alt-left', 'fas fa-long-arrow-alt-down', 'fas fa-lock-open', 'fas fa-lock', 'fas fa-location-arrow', 'fas fa-list-ul', 'fas fa-list-ol', 'fas fa-list-alt', 'fas fa-list-alt', 'fas fa-list', 'fab fa-linux', 'fab fa-linode', 'fab fa-linkedin-in', 'fab fa-linkedin', 'fab fa-line', 'fas fa-lightbulb', 'far fa-lightbulb', 'far fa-life-ring', 'fas fa-life-ring', 'fas fa-level-up-alt', 'fas fa-level-down-alt', 'fas fa-less-than-equal', 'fas fa-less-than', 'fab fa-less', 'fas fa-lemon', 'far fa-lemon', 'fab fa-leanpub', 'fas fa-leaf', 'fas fa-layer-group', 'fas fa-laugh-wink', 'fas fa-laugh-wink', 'fas fa-laugh-squint', 'fas fa-laugh-squint', 'fas fa-laugh-beam', 'fas fa-laugh-beam', 'fas fa-laugh', 'fas fa-laugh', 'fab fa-lastfm-square', 'fab fa-lastfm', 'fab fa-laravel', 'fas fa-laptop-medical', 'fas fa-laptop-code', 'fas fa-laptop', 'fas fa-language', 'fas fa-landmark', 'fas fa-won-sign', 'fab fa-korvue', 'fas fa-kiwi-bird', 'fas fa-kiss-wink-heart', 'fas fa-kiss-wink-heart', 'fas fa-kiss-beam', 'fas fa-kiss-beam', 'fas fa-kiss', 'fas fa-kiss', 'fab fa-kickstarter-k', 'fab fa-kickstarter', 'fas fa-khanda', 'fab fa-keycdn', 'fas fa-keyboard', 'far fa-keyboard', 'fab fa-keybase', 'fas fa-key', 'fab fa-kaggle', 'fas fa-kaaba', 'fab fa-jsfiddle', 'fab fa-js-square', 'fab fa-js', 'fas fa-journal-whills', 'fab fa-joomla', 'fas fa-joint', 'fab fa-joget', 'fab fa-jira', 'fab fa-jenkins', 'fab fa-jedi-order', 'fas fa-jedi', 'fab fa-java', 'fab fa-itunes-note', 'fab fa-itunes', 'fab fa-itch-io', 'fas fa-italic', 'fab fa-ioxhost', 'fab fa-invision', 'fas fa-transgender', 'fab fa-internet-explorer', 'fab fa-intercom', 'fab fa-instagram', 'fas fa-rupee-sign', 'fas fa-info-circle', 'fas fa-info', 'fas fa-infinity', 'fas fa-industry', 'fas fa-indent', 'fas fa-inbox', 'fab fa-imdb', 'fas fa-images', 'fas fa-images', 'fas fa-shekel-sign', 'fas fa-igloo', 'fas fa-id-card-alt', 'fas fa-id-badge', 'fas fa-id-badge', 'fas fa-icons', 'fas fa-icicles', 'fas fa-ice-cream', 'fas fa-i-cursor', 'fab fa-hubspot', 'fab fa-html5', 'fas fa-hryvnia', 'fab fa-houzz', 'fas fa-house-damage', 'fas fa-hourglass', '/fas fa-hourglass-end/', 'fas fa-hourglass-end', 'fas fa-hourglass-half', 'fas fa-hourglass-start', 'far fa-hourglass', 'fab fa-hotjar', 'fas fa-bed', 'fas fa-bed', 'fas fa-hotdog', 'fas fa-hot-tub', 'fas fa-hospital-symbol', 'fas fa-hospital', 'fas fa-hospital-alt', 'far fa-hospital', 'fas fa-horse-head', 'fas fa-horse', 'fab fa-hornbill', 'fab fa-hooli', 'fas fa-home', 'fas fa-holly-berry', 'fas fa-hockey-puck', 'fas fa-history', 'fab fa-hire-a-helper', 'fab fa-hips', 'fas fa-hippo', 'fas fa-hiking', 'fas fa-highlighter', 'fas fa-helicopter', 'fas fa-heartbeat', 'fas fa-heart', 'fas fa-heart-broken', 'far fa-heart', 'fas fa-headset', 'fas fa-headphones-alt', 'fas fa-headphones', 'fas fa-heading', 'fas fa-hdd', 'far fa-hdd', 'fas fa-haykal', 'fas fa-hat-wizard', 'fas fa-hashtag', 'fas fa-hard-hat', 'fas fa-hanukiah', 'fas fa-handshake', 'far fa-handshake', 'fas fa-hands-helping', 'fas fa-hands', 'fas fa-hand-spock', 'far fa-hand-spock', 'fas fa-hand-scissors', 'far fa-hand-scissors', 'fas fa-hand-rock', 'far fa-hand-rock', 'fas fa-hand-pointer', 'far fa-hand-pointer', 'far fa-hand-point-up', 'far fa-hand-point-right', 'far fa-hand-point-left', 'far fa-hand-point-down', 'fas fa-hand-peace', 'far fa-hand-peace', 'fas fa-hand-paper', 'far fa-hand-paper', 'fas fa-hand-point-up', 'fas fa-hand-point-right', 'fas fa-hand-point-left', 'fas fa-hand-point-down', 'fas fa-hand-middle-finger', 'fas fa-hand-lizard', 'far fa-hand-lizard', 'fas fa-hand-holding-usd', 'fas fa-hand-holding-heart', 'fas fa-hand-holding', 'fas fa-hamsa', 'fas fa-hammer', 'fas fa-hamburger', 'fab fa-hackerrank', 'fab fa-hacker-news-square', 'fas fa-h-square', 'fab fa-gulp', 'fas fa-guitar', 'fab fa-grunt', 'fas fa-users', 'fab fa-gripfire', 'fas fa-grip-vertical', 'fas fa-grip-lines-vertical', 'fas fa-grip-lines', 'fas fa-grip-horizontal', 'fas fa-grin-wink', 'fas fa-grin-wink', 'fas fa-grin-tongue-wink', 'fas fa-grin-tongue-wink', 'fas fa-grin-tongue-squint', 'fas fa-grin-tongue-squint', 'fas fa-grin-tongue', 'fas fa-grin-tongue', 'fas fa-grin-tears', 'fas fa-grin-tears', 'fas fa-grin-stars', 'fas fa-grin-stars', 'fas fa-grin-squint-tears', 'fas fa-grin-squint-tears', 'fas fa-grin-squint', 'fas fa-grin-squint', 'fas fa-grin-hearts', 'fas fa-grin-hearts', 'fas fa-grin-beam-sweat', 'fas fa-grin-beam-sweat', 'fas fa-grin-beam', 'fas fa-grin-beam', 'fas fa-grin-alt', 'fas fa-grin-alt', 'fas fa-grin', 'fas fa-grin', 'fas fa-grimace', 'fas fa-grimace', 'fas fa-greater-than-equal', 'fas fa-greater-than', 'fab fa-grav', 'fas fa-gopuram', 'fab fa-google-wallet', 'fab fa-google-plus-square', 'fab fa-google-plus-g', 'fab fa-google-plus', 'fab fa-google-play', 'fab fa-google-drive', 'fab fa-google', 'fab fa-goodreads-g', 'fab fa-goodreads', 'fas fa-golf-ball', 'fab fa-gofore', 'fas fa-globe-europe', 'fas fa-globe-asia', 'fas fa-globe-americas', 'fas fa-globe-africa', 'fas fa-globe', 'fab fa-glide-g', 'fab fa-glide', 'fas fa-glasses', 'fas fa-glass-whiskey', 'fas fa-glass-martini-alt', 'fas fa-glass-cheers', 'fas fa-glass-martini', 'fab fa-gratipay', 'fab fa-gitter', 'fab fa-gitlab', 'fab fa-gitkraken', 'fab fa-github-square', 'fab fa-github-alt', 'fab fa-github', 'fab fa-git-square', 'fab fa-git-alt', 'fab fa-git', 'fas fa-gifts', 'fas fa-gift', 'fas fa-ghost', 'fab fa-gg-circle', 'fab fa-gg', 'fab fa-get-pocket', 'fas fa-genderless', 'fas fa-gem', 'fas fa-cogs', 'fas fa-cog', 'fab fa-empire', 'fas fa-pound-sign', 'fas fa-gavel', 'fas fa-gas-pump', 'fas fa-gamepad', 'fab fa-galactic-senate', 'fab fa-galactic-republic', 'fas fa-futbol', 'fas fa-funnel-dollar', 'fab fa-fulcrum', 'fas fa-frown-open', 'fas fa-frown-open', 'fas fa-frown', 'far fa-frown', 'fas fa-frog', 'fab fa-freebsd', 'fab fa-free-code-camp', 'fab fa-foursquare', 'fas fa-forward', 'fab fa-forumbee', 'fab fa-fort-awesome-alt', 'fab fa-fort-awesome', 'fas fa-football-ball', 'fab fa-fonticons-fi', 'fab fa-fonticons', 'fab fa-font-awesome-flag', 'fab fa-font-awesome-alt', 'fas fa-font', 'fas fa-folder-plus', 'fas fa-folder-open', 'far fa-folder-open', 'fas fa-folder', 'fas fa-folder-minus', 'far fa-folder', 'fab fa-fly', 'fas fa-flushed', 'fas fa-flushed', 'fas fa-save', 'fab fa-flipboard', 'fab fa-flickr', 'fas fa-flask', 'fas fa-bolt', 'fas fa-flag-usa', 'fas fa-flag', 'fas fa-flag-checkered', 'far fa-flag', 'fas fa-fist-raised', 'fas fa-fish', 'fab fa-firstdraft', 'fab fa-first-order-alt', 'fab fa-first-order', 'fas fa-first-aid', 'fab fa-firefox', 'fas fa-fire-extinguisher', 'fas fa-fire-alt', 'fas fa-fire', 'fas fa-fingerprint', 'fas fa-filter', 'fas fa-film', 'fas fa-fill-drip', 'fas fa-fill', 'fas fa-copy', 'fas fa-file-word', 'far fa-file-word', 'fas fa-file-video', 'far fa-file-video', 'fas fa-file-upload', 'fas fa-file-alt', 'far fa-file-alt', 'fas fa-file-signature', 'fas fa-file-prescription', 'fas fa-file-powerpoint', 'far fa-file-powerpoint', 'far fa-file-image', 'fas fa-file-pdf', 'far fa-file-pdf', 'fas fa-file', 'fas fa-file-medical-alt', 'fas fa-file-medical', 'fas fa-file-invoice-dollar', 'fas fa-file-invoice', 'fas fa-file-import', 'fas fa-file-image', 'fas fa-file-export', 'fas fa-file-excel', 'far fa-file-excel', 'fas fa-file-download', 'fas fa-file-csv', 'fas fa-file-contract', 'fas fa-file-code', 'far fa-file-code', 'fas fa-file-audio', 'far fa-file-audio', 'fas fa-file-archive-o', 'far fa-file-archive', 'far fa-file', 'fab fa-figma', 'fas fa-fighter-jet', 'fas fa-female', 'fas fa-rss', 'fab fa-fedora', 'fab fa-fedex', 'fas fa-feather-alt', 'fas fa-feather', 'fas fa-fax', 'fas fa-fast-forward', 'fas fa-fast-backward', 'fab fa-fantasy-flight-games', 'fas fa-fan', 'fab fa-facebook-square', 'fab fa-facebook', 'fab fa-facebook-messenger', 'fab fa-facebook-f', 'fab fa-font-awesome', 'fas fa-eye-slash', 'fas fa-eye-slash', 'fas fa-eye-dropper', 'fas fa-eye', 'fas fa-eye', 'fas fa-external-link-square-alt', 'fas fa-external-link-alt', 'fab fa-expeditedssl', 'fas fa-expand', 'fas fa-exclamation-circle', 'fas fa-exclamation', 'fas fa-exchange-alt', 'fab fa-evernote', 'fas fa-euro', 'fab fa-etsy', 'fas fa-ethernet', 'fab fa-ethereum', 'fab fa-erlang', 'fas fa-eraser', 'fas fa-equals', 'fab fa-envira', 'fas fa-envelope-square', 'fas fa-envelope-open-text', 'fas fa-envelope-open', 'far fa-envelope-open', 'fas fa-envelope', 'fas fa-envelope', 'fas fa-envelope', 'fab fa-ember', 'fab fa-ello', 'fas fa-ellipsis-v', 'fas fa-ellipsis-h', 'fab fa-elementor', 'fas fa-eject', 'fas fa-egg', 'fab fa-sellcast', 'fas fa-edit', 'fab fa-edge', 'fab fa-ebay', 'fab fa-earlybirds', 'fab fa-dyalog', 'fas fa-dungeon', 'fas fa-dumpster-fire', 'fas fa-dumpster', 'fas fa-dumbbell', 'fab fa-drupal', 'fas fa-drumstick-bite', 'fas fa-drum-steelpan', 'fas fa-drum', 'fab fa-dropbox', 'fas fa-id-card', 'far fa-id-card', 'fab fa-dribbble-square', 'fab fa-dribbble', 'fas fa-draw-polygon', 'fas fa-dragon', 'fas fa-drafting-compass', 'fab fa-draft2digital', 'fas fa-download', 'fas fa-dove', 'fas fa-dot-circle', 'far fa-dot-circle', 'fas fa-door-open', 'fas fa-door-closed', 'fas fa-donate', 'fas fa-dolly-flatbed', 'fas fa-dolly', 'fas fa-dollar-sign', 'fas fa-dog', 'fab fa-docker', 'fab fa-dochub', 'fas fa-dna', 'fas fa-dizzy', 'fas fa-dizzy', 'fas fa-divide', 'fab fa-discourse', 'fab fa-discord', 'fas fa-directions', 'fas fa-digital-tachograph', 'fab fa-digital-ocean', 'fab fa-digg', 'fas fa-dice-two', 'fas fa-dice-three', 'fas fa-dice-six', 'fas fa-dice-one', 'fas fa-dice-four', 'fas fa-dice-five', 'fas fa-dice-d6', 'fas fa-dice-d20', 'fas fa-dice', 'fab fa-diaspora', 'far fa-gem', 'fas fa-diagnoses', 'fab fa-dhl', 'fas fa-dharmachakra', 'fab fa-deviantart', 'fab fa-dev', 'fas fa-desktop', 'fab fa-deskpro', 'fab fa-deploydog', 'fas fa-democrat', 'fab fa-delicious', 'fas fa-outdent', 'fas fa-deaf', 'fas fa-database', 'fab fa-dashcube', 'fas fa-tachometer-alt', 'fab fa-d-and-d-beyond', 'fab fa-d-and-d', 'fab fa-cuttlefish', 'fas fa-utensils', 'fas fa-cubes', 'fas fa-cube', 'fab fa-css3-alt', 'fab fa-css3', 'fas fa-crutch', 'fas fa-crown', 'fas fa-crow', 'fas fa-crosshairs', 'fas fa-cross', 'fas fa-crop-alt', 'fas fa-crop', 'fab fa-critical-role', 'fas fa-credit-card', 'fas fa-credit-card', 'fab fa-creative-commons-zero', 'fab fa-creative-commons-share', 'fab fa-creative-commons-sampling-plus', 'fab fa-creative-commons-sampling', 'fab fa-creative-commons-sa', 'fab fa-creative-commons-remix', 'fab fa-creative-commons-pd-alt', 'fab fa-creative-commons-pd', 'fab fa-creative-commons-nd', 'fab fa-creative-commons-nc-jp', 'fab fa-creative-commons-nc-eu', 'fab fa-creative-commons-nc', 'fab fa-creative-commons-by', 'fab fa-creative-commons', 'fab fa-cpanel', 'fas fa-couch', 'fab fa-cotton-bureau', 'fas fa-copyright', 'fas fa-copyright', 'far fa-copy', 'fas fa-cookie-bite', 'fas fa-cookie', 'fab fa-contao', 'fab fa-connectdevelop', 'fab fa-confluence', 'fas fa-concierge-bell', 'fas fa-compress-arrows-alt', 'fas fa-compress', 'fas fa-compass', 'fas fa-compass', 'fas fa-compact-disc', 'fas fa-comments', 'fas fa-comments-dollar', 'far fa-comments', 'fas fa-comment-dots', 'far fa-comment-dots', 'fas fa-comment-slash', 'fas fa-comment', 'fas fa-comment-medical', 'fas fa-comment-dollar', 'fas fa-comment-alt', 'fas fa-comment-alt', 'far fa-comment', 'fas fa-columns', 'fas fa-coins', 'fas fa-coffee', 'fab fa-codiepie', 'fab fa-codepen', 'fas fa-code-branch', 'fas fa-code', 'fas fa-cocktail', 'fas fa-yen-sign', 'fab fa-cloudversify', 'fab fa-cloudsmith', 'fab fa-cloudscale', 'fas fa-cloud-upload-alt', 'fas fa-cloud-sun-rain', 'fas fa-cloud-sun', 'fas fa-cloud-showers-heavy', 'fas fa-cloud-rain', 'fas fa-cloud-moon-rain', 'fas fa-cloud-moon', 'fas fa-cloud-meatball', 'fas fa-cloud-download-alt', 'fas fa-cloud', 'far fa-closed-captioning', 'fas fa-times', 'fas fa-clone', 'fas fa-clone', 'fas fa-clock', 'far fa-clock', 'fas fa-clipboard-list', 'fas fa-clipboard-check', 'fas fa-clipboard', 'fas fa-clinic-medical', 'fas fa-city', 'fas fa-circle-notch', 'fas fa-circle', 'far fa-circle', 'fas fa-church', 'fab fa-chromecast', 'fab fa-chrome', 'fas fa-child', 'fas fa-chevron-up', 'fas fa-chevron-right', 'fas fa-chevron-left', 'fas fa-chevron-down', 'fas fa-chevron-circle-up', 'fas fa-chevron-circle-right', 'fas fa-chevron-circle-left', 'fas fa-chevron-circle-down', 'fas fa-chess-rook', 'fas fa-chess-queen', 'fas fa-chess-pawn', 'fas fa-chess-knight', 'fas fa-chess-king', 'fas fa-chess-board', 'fas fa-chess-bishop', 'fas fa-chess', 'fas fa-cheese', 'fas fa-check-square', 'far fa-check-square', 'fas fa-check-double', 'fas fa-check-circle', 'far fa-check-circle', 'fas fa-check', 'fas fa-chart-line', 'fas fa-chart-area', 'fas fa-charging-station', 'fas fa-chalkboard-teacher', 'fas fa-chalkboard', 'fas fa-chair', 'fas fa-unlink', 'fas fa-link', 'fas fa-certificate', 'fab fa-centos', 'fab fa-centercode', 'fab fa-cc-visa', 'fab fa-cc-stripe', 'fab fa-cc-paypal', 'fab fa-cc-mastercard', 'fab fa-cc-jcb', 'fab fa-cc-discover', 'fab fa-cc-diners-club', 'fab fa-cc-apple-pay', 'fab fa-cc-amex', 'fab fa-cc-amazon-pay', 'fas fa-closed-captioning', 'fas fa-cat', 'fas fa-cash-register', 'fas fa-cart-plus', 'fas fa-cart-arrow-down', 'fas fa-carrot', 'fas fa-caret-up', 'fas fa-caret-square-up', 'fas fa-caret-square-right', 'fas fa-caret-square-left', 'fas fa-caret-square-down', 'fas fa-caret-right', 'fas fa-caret-left', 'fas fa-caret-down', 'fas fa-car-side', 'fas fa-car-crash', 'fas fa-car-battery', 'fas fa-car-alt', 'fas fa-car', 'fas fa-capsules', 'fas fa-cannabis', 'fas fa-candy-cane', 'fab fa-canadian-maple-leaf', 'fas fa-campground', 'fas fa-camera-retro', 'fas fa-camera', 'fas fa-calendar-week', 'fas fa-calendar-times', 'far fa-calendar-times', 'fas fa-calendar-plus', 'far fa-calendar-plus', 'fas fa-calendar', 'fas fa-calendar-minus', 'fas fa-calendar-minus', 'fas fa-calendar-day', 'fas fa-calendar-check', 'far fa-calendar-check', 'fas fa-calendar-alt', 'far fa-calendar', 'far fa-calendar', 'fas fa-calculator', 'fas fa-taxi', 'fab fa-buysellads', 'fas fa-business-time', 'fas fa-bus-alt', 'fas fa-bus', 'fab fa-buromobelexperte', 'fas fa-burn', 'fas fa-bullseye', 'fas fa-bullhorn', 'fas fa-building', 'far fa-building', 'fas fa-bug', 'fab fa-buffer', 'fas fa-brush', 'fas fa-broom', 'fas fa-broadcast-tower', 'fas fa-briefcase-medical', 'fas fa-briefcase', 'fas fa-bread-slice', 'fas fa-brain', 'fas fa-braille', 'fas fa-boxes', 'fas fa-box-open', 'fas fa-box', 'fas fa-bowling-ball', 'fas fa-border-style', 'fas fa-border-none', 'fas fa-border-all', 'fab fa-bootstrap', 'fas fa-bookmark', 'far fa-bookmark', 'fas fa-book-reader', 'fas fa-book-open', 'fas fa-book-medical', 'fas fa-book-dead', 'fas fa-book', 'fas fa-bong', 'fas fa-bone', 'fas fa-bomb', 'fas fa-bold', 'fab fa-bluetooth-b', 'fab fa-bluetooth', 'fab fa-blogger-b', 'fab fa-blogger', 'fas fa-blog', 'fas fa-blind', 'fas fa-blender-phone', 'fas fa-blender', 'fab fa-blackberry', 'fab fa-black-tie', 'fab fa-bity', 'fab fa-bitcoin', 'fab fa-bitcoin', 'fab fa-bitbucket', 'fas fa-birthday-cake', 'fas fa-biohazard', 'fas fa-binoculars', 'fab fa-bimobject', 'fas fa-biking', 'fas fa-bicycle', 'fas fa-bible', 'fas fa-bezier-curve', 'fas fa-bell-slash', 'far fa-bell-slash', 'fas fa-bell', 'far fa-bell', 'fab fa-behance-square', 'fab fa-behance', 'fas fa-beer', 'fab fa-battle-net', 'fas fa-battery-three-quarters', 'fas fa-battery-half', 'fas fa-battery-quarter', 'fas fa-battery-empty', 'fas fa-battery-full', 'fas fa-bath', 'fas fa-basketball-ball', 'fas fa-baseball-ball', 'fas fa-barcode', 'fas fa-chart-bar', 'far fa-chart-bar', 'fas fa-university', 'fab fa-bandcamp', 'fas fa-band-aid', 'fas fa-ban', 'fas fa-balance-scale-right', 'fas fa-balance-scale-left', 'fas fa-balance-scale', 'fas fa-bacon', 'fas fa-backward', 'fas fa-backspace', 'fas fa-baby-carriage', 'fas fa-baby', 'fab fa-aws', 'fas fa-award', 'fab fa-aviato', 'fab fa-avianex', 'fab fa-autoprefixer', 'fas fa-audio-description', 'fab fa-audible', 'fas fa-atom', 'fab fa-atlassian', 'fas fa-atlas', 'fas fa-at', 'fab fa-asymmetrik', 'fas fa-asterisk', 'fas fa-assistive-listening-systems', 'fas fa-american-sign-language-interpreting', 'fab fa-artstation', 'fas fa-arrows-alt-v', 'fas fa-arrows-alt-h', 'fas fa-expand-arrows-alt', 'fas fa-arrows-alt', 'fas fa-arrow-up', 'fas fa-arrow-right', 'fas fa-arrow-left', 'fas fa-arrow-down', 'fas fa-arrow-circle-up', 'fas fa-arrow-circle-right', 'fas fa-arrow-alt-circle-up', 'fas fa-arrow-alt-circle-right', 'fas fa-arrow-alt-circle-left', 'fas fa-arrow-alt-circle-down', 'fas fa-arrow-circle-left', 'fas fa-arrow-circle-down', 'far fa-arrow-alt-circle-up', 'far fa-arrow-alt-circle-right', 'far fa-arrow-alt-circle-left', 'far fa-arrow-alt-circle-down', 'fas fa-archway', 'fas fa-archive', 'fab fa-apple-pay', 'fas fa-apple-alt', 'fab fa-apple', 'fab fa-apper', 'fab fa-app-store-ios', 'fab fa-app-store', 'fas fa-ankh', 'fab fa-angular', 'fab fa-angrycreative', 'fas fa-angry', 'fas fa-angry', 'fas fa-angle-up', 'fas fa-angle-right', 'fas fa-angle-left', 'fas fa-angle-down', 'fas fa-angle-double-up', 'fas fa-angle-double-right', 'fas fa-angle-double-left', 'fas fa-angle-double-down', 'fab fa-angellist', 'fab fa-android', 'fas fa-anchor', 'fab fa-amilia', 'fas fa-ambulance', 'fab fa-amazon-pay', 'fab fa-amazon', 'fas fa-allergies', 'fab fa-alipay', 'fas fa-align-right', 'fas fa-align-left', 'fas fa-align-justify', 'fas fa-align-center', 'fab fa-algolia', 'fab fa-airbnb', 'fas fa-air-freshener', 'fab fa-affiliatetheme', 'fab fa-adversal', 'fab fa-adobe', 'fab fa-adn', 'fas fa-adjust', 'fas fa-address-card', 'fas fa-address-book', 'far fa-address-book', 'fas fa-ad', 'fab fa-acquisitions-incorporated', 'fab fa-accusoft', 'fab fa-500px'
		);

		return $replace_by;
	}



	/**
	 * @since 1.0.1
	 * gutenburg Dropdown Menu Add
	 */
	public function wp_importer_esacpe(){
		if( /* defined('WP_LOAD_IMPORTERS') && */ is_admin() ){
			add_filter( 'wp_import_post_meta', array( $this, 'import_post_meta_esacpe' ) );
		}
	}
	public function import_post_meta_esacpe( $post_meta ){
		foreach ( $post_meta as &$meta ) {
			if ( '_wppb_content' === $meta['key'] ) {
				$meta['value'] = wp_slash( $meta['value'] );
				break;
			}
		}
		return $post_meta;
	}

	/**
	 * @since 1.0.0
	 * gutenburg Dropdown Menu Add
	 */
	public function wppb_add_btn_to_gutenburg_dropdown(){
		global $typenow;
		$wppb_page_url = wppb_helper()->get_editor_url();
		$wppb_page_url = add_query_arg( array('post_type' => $typenow), $wppb_page_url);
		$supported_post_types    = wppb_helper()->wppb_supports_post_types();
		if (! in_array($typenow, $supported_post_types)){
			return;
		}
		?>
        <script type="text/javascript">
            document.addEventListener( 'DOMContentLoaded', function() {
                var dropdown = document.querySelector( '#split-page-title-action .dropdown' );
                if ( ! dropdown ) {
                    return;
                }
                var url = '<?php echo $wppb_page_url; ?>';
                dropdown.insertAdjacentHTML( 'afterbegin', '<a href="' + url + '">WP Pagebuilder</a>' );
            } );
        </script>
		<?php
	}

	/**
	 * @since 1.0.0
	 * Add Image Size for Posts Addons
	 */
	public function add_image_size() {
		add_image_size( 'wppb-medium', 600, 450, true );
	}

	public function add_extra_body_class($classes){
		global $pagenow;

		if ($pagenow == 'post.php') {
			$current_editor = get_post_meta(get_the_ID(), '_wppb_current_post_editor', true);

		    if ($current_editor){
			    $classes .= " currently-activated-editor-{$current_editor} ";
		    }
		}
		return $classes;
	}

	public function add_required_assets(){
	    $this->is_current_editor_gutenberg = true;
    }

	public function add_required_template_to_guttenberg_editor() {
		if ( ! $this->is_current_editor_gutenberg )
		    return;
		?>
        <script id="wp-pagebuilder-to-gutenberg-switch-mode" type="text/html">
            <div id="wp-pagebuilder-switch-to-gutenberg">
                <a href="<?php echo admin_url('post.php?post='.get_the_ID().'&action=wppb_editor') ?>" id="wp-pagebuilder-switch-to-gutenberg-btn" class="wppb-backend-btn wppb-primary-btn edit-with-wppb-builder">
	                <?php echo __( 'Edit with WP Page Builder', 'wp-pagebuilder' ); ?>
                </a>
            </div>
        </script>
		<?php
	}


}